@@ -19,7 +19,7 @@ try:
 except:
 	from halo import Halo
 
-from kxy.api import APIClient, upload_data, approx_opt_remaining_time
+from kxy.api import APIClient, upload_data
 
 # Cache old job ids to avoid being charged twice for the same job.
 VALUATION_JOB_IDS = {}
@@ -115,8 +115,9 @@ def data_valuation(data_df, target_column, problem_type, snr='auto'):
 
 						try:
 							response = api_response.json()
-							if 'ETA' in response:
-								spinner.text = 'Waiting for results from the backend. ETA: %s.' % response['ETA']
+							if 'eta' in response:
+								progress_text = '%s% Completed.' % response['progress_pct'] if 'progress_pct' in response else ''
+								spinner.text = 'Waiting for results from the backend. ETA: %s. %s' % (response['eta'], progress_text)
 						except:
 							pass
 
